:tocdepth: 2

API
====================

PyDbLite.PyDbLite API
-------------------------------

.. automodule:: pydblite.pydblite
   :members:

.. autoclass:: pydblite.pydblite._Base
   :members:

   .. automethod:: __init__


PyDbLite.SQLite API
-------------------------------

.. automodule:: pydblite.sqlite
   :members:

.. autoclass:: pydblite.sqlite.Database
   :members:
   :special-members:
   :private-members:


.. autoclass:: pydblite.sqlite.Table
   :members:
   :special-members:
   :private-members:
   :exclude-members: __weakref__


PyDbLite.common API
-------------------------------

.. automodule:: pydblite.common
    :members:
    :special-members:
    :exclude-members: __weakref__

.. .autoclass:: pydblite.common.Filter
   :members:
   :special-members:
   :exclude-members: __weakref__
